from setuptools import setup

setup(name='prob_package_1',
      version='0.0',
      description='Gaussian and Binomial distributions',
      packages=['prob_package_1'],
      author="Vinamr Bajaj",
      author_email="bajajvinamr@gmail.com",
      zip_safe=False)
